@@ -26,49 +26,24 @@ Moose::Exporter->setup_import_methods(
     as_is => ['load_xsd'],
 );
 
-our $VERSION     = version->new('0.0.7');
+extends 'W3C::SOAP::Parser';
+
+our $VERSION     = version->new('0.01');
 
 subtype xsd_documents =>
     as 'ArrayRef[W3C::SOAP::XSD::Document]';
 coerce xsd_documents =>
     from 'W3C::SOAP::XSD::Document',
     via {[$_]};
-has documents => (
-    is       => 'rw',
+has '+document' => (
     isa      => 'xsd_documents',
     coerce   => 1,
 );
-has template => (
-    is       => 'rw',
-    isa      => 'Template',
-    predicate => 'has_template',
-);
 has ns_module_map => (
     is       => 'rw',
     isa      => 'HashRef[Str]',
     required => 1,
 );
-has lib => (
-    is       => 'rw',
-    isa      => 'Str',
-    predicate => 'has_lib',
-);
-
-around BUILDARGS => sub {
-    my ($orig, $class, @args) = @_;
-    my $args
-        = !@args     ? {}
-        : @args == 1 ? $args[0]
-        :              {@args};
-
-    for my $arg ( keys %$args ) {
-        if ( $arg eq 'location' || $arg eq 'string' ) {
-            $args->{documents} = W3C::SOAP::XSD::Document->new($args);
-        }
-    }
-
-    return $class->$orig($args);
-};
 
 sub write_modules {
     my ($self) = @_;
@@ -134,7 +109,7 @@ sub write_modules {
 
             # write the complex type module
             $self->write_module(
-                'xsd_complex_type.pm.tt',
+                'xsd/complex_type.pm.tt',
                 {
                     xsd     => $xsd,
                     module  => $type_module,
@@ -147,7 +122,7 @@ sub write_modules {
 
         # write the simple types library
         $self->write_module(
-            'xsd_base.pm.tt',
+            'xsd/base.pm.tt',
             {
                 xsd => $xsd,
             },
@@ -156,7 +131,7 @@ sub write_modules {
 
         # write the "XSD" elements module
         $self->write_module(
-            'xsd.pm.tt',
+            'xsd/pm.tt',
             {
                 xsd => $xsd,
                 parents => \@parents,
@@ -187,7 +162,7 @@ sub write_module {
 
 sub get_schemas {
     my ($self) = @_;
-    my @xsds   = @{ $self->documents };
+    my @xsds   = @{ $self->document };
     my %xsd;
 
     # import all schemas
@@ -238,6 +213,7 @@ sub dynamic_classes {
     # construct the in memory module names
     for my $xsd (@xsds) {
         $xsd->module_base('Dynamic::XSD');
+        $xsd->module;
     }
 
     my %seen;
@@ -449,7 +425,7 @@ W3C::SOAP::XSD::Parser - Parse an W3C::SOAP::XSD::Document and create perl modul
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Parser version 0.0.7.
+This documentation refers to W3C::SOAP::XSD::Parser version 0.01.
 
 =head1 SYNOPSIS
 
